@@ -5,7 +5,8 @@ testthat::test_that(
   "Testing if data sets returns a data.frame if not authenticated", {
 
     df = nsrr_datasets(token = NULL)
-    if (attributes(df)$status_code == 200) {
+
+    if (all(attributes(df)$status_code == 200)) {
       testthat::expect_is(df, "data.frame")
     }
 
@@ -16,7 +17,7 @@ testthat::test_that("Testing if data sets returns a data.frame", {
   token = nsrr_token()
   if (!is.null(token)) {
     df = nsrr_datasets(token = token)
-    if (attributes(df)$status_code == 200) {
+    if (all(attributes(df)$status_code == 200)) {
       testthat::expect_is(df, "data.frame")
     }
   }
